@@ -1,9 +1,12 @@
 package Class::MakeMethods::Template;
 
+use strict;
+use Carp;
+
 use Class::MakeMethods '-isasubclass';
 
-use Carp;
-use strict;
+use vars qw( $VERSION );
+$VERSION = 1.005;
 
 sub _diagnostic { &Class::MakeMethods::_diagnostic }
 
@@ -44,8 +47,9 @@ sub _definition {
   while ( ! ref $target ) {
     $target =~ s/\s.*//;
     
-    # If method name contains a colon, call the method on the indicated class.
-    my $call_class = ( ( $target =~ s/^(.*)\:// ) 
+    # If method name contains a colon or double colon, call the method on the
+    # indicated class.
+    my $call_class = ( ( $target =~ s/^(.*)\:{1,2}// ) 
       ? Class::MakeMethods::_find_subclass($class, $1) : $class );
     $target = $call_class->named_method( $target );
   }
@@ -468,11 +472,26 @@ __END__
 
 Class::MakeMethods::Template - Extensible code templates 
 
+
+=head1 SYNOPSIS
+
+  package MyObject;
+  use Class::MakeMethods::Template::Hash (
+    'new'       => 'new',
+    'string'    => 'foo',
+    'number'    => 'bar',
+  );
+   
+  my $obj = MyObject->new( foo => "Foozle", bar => 23 );
+  print $obj->foo();
+  $obj->bar(42);
+
+
 =head1 MOTIVATION
 
 If you compare the source code of some of the closure-generating
 methods provided by other subclasses of Class::MakeMethods,
-such as the C<hash> accessors provided by the various Basic
+such as the C<hash> accessors provided by the various Standard::*
 subclasses, you will notice a fair amount of duplication. This
 module provides a way of assembling common pieces of code to
 facilitate support the maintenance of much larger libraries of
@@ -481,7 +500,9 @@ generated methods.
 
 =head1 DESCRIPTION
 
-This module extends the Class::MakeMethods framework by providing an abstract superclass for extensible code-templating method generators.
+This module extends the Class::MakeMethods framework by providing
+an abstract superclass for extensible code-templating method
+generators.
 
 Common types of methods are generalized into B<template definitions>.
 For example, C<Template::Generic>'s C<new> provides a template for
@@ -489,14 +510,14 @@ methods that create object instances, while C<Template::Generic>'s
 C<scalar> is a template for methods that allow you to get and set
 individual scalar values.
 
-Thse definitions are then re-used and modified by various
-B<template subclasses>. For example, the C<Template::Hash>
-subclass supports blessed-hash objects, while the C<Template::Static>
-subclass supports shared data; each of them includes an appropriate
-version of the C<scalar> accessor template for those object types.
+Thse definitions are then re-used and modified by various B<template
+subclasses>. For example, the C<Template::Hash> subclass supports
+blessed-hash objects, while the C<Template::Static> subclass supports
+shared data; each of them includes an appropriate version of the
+C<scalar> accessor template for those object types.
 
-Each template defines one or more B<behaviors>, individual
-methods which can be installed in a calling package, and B<interfaces>,
+Each template defines one or more B<behaviors>, individual methods
+which can be installed in a calling package, and B<interfaces>,
 which select from those behaviours and indicate the names to install
 the methods under.
 
@@ -526,7 +547,7 @@ You can install methods in a different package by passing C<-TargetClass =E<gt>
 
 See L<Class::MakeMethods> for more details.
 
-=head2 Basic Declaration Syntax
+=head2 Passing Parameters
 
 The following types of Basic declarations are supported:
 
@@ -546,7 +567,7 @@ I<generator_type> => [ "I<name_1>", "I<name_2>", ...]
 
 =back
 
-See L<Class::MakeMethods::Catalog> for a list of the supported values of I<generator_type>.
+See L<Class::MakeMethods::Docs::Catalog/"TEMPLATE CLASSES"> for a list of the supported values of I<generator_type>.
 
 For each method name you provide, a subroutine of the indicated
 type will be generated and installed under that name in your module.
@@ -588,7 +609,7 @@ contained declaration with that name and any associated hash values.
 
 Basic declarations, as described above, are treated as having an empty parameter hash.
 
-=head2 Template Declaration Syntax
+=head2 Default Parameters
 
 A set of default parameters to be used for several declarations
 may be specified using any of the following types of arguments to
@@ -669,13 +690,13 @@ depending on the rules specified by the interface.
 interface
 
 The name of a predefined interface, or a reference to a custom
-interface, to use for this meta-method.
+interface, to use for this meta-method. See L</Selecting Interfaces>, below.
 
 =item *
 
 modifier
 
-The names of one or more predefined modifier flags.
+The names of one or more predefined modifier flags. See L</Selecting Modifiers>, below.
 
 =back
 
@@ -725,7 +746,7 @@ Example: The following defines counter (*, *_incr, *_reset)
 meta-methods j and k, which use the hash keys j_index and k_index
 to fetch and store their values.
 
-  use Class::MakeMethods
+  use Class::MakeMethods::Template::Hash
     counter => [ '-hash_key' => '*_index', qw/ j k / ];
 
 (See L<Class::MakeMethods::Template::Hash> for information about the C<hash_key> parameter.)
@@ -846,461 +867,19 @@ Method c croaks if it's called from outside of the current package.
 See the documentation for each template to learn which modifiers it supports.
 
 
-=head1 SUBCLASS CATALOG
+=head2 Runtime Parameter Access
 
-This list summarizes the various subclasses of Class::MakeMethods included
-in this distribution, and the method types each one provides. 
+If the meta-method is defined using an interface which includes the
+attributes method, run-time access to meta-method parameters is
+available.
 
-See the documentation for each implementation for more details
-about the features it provides.
+Example: The following defines a counter meta-method named y, and
+then later changes the 'join' parameter for that method at runtime.
 
-
-=head2 Template::Universal (Any)
-
-Meta-methods for any type of object.
-
-=over 4
-
-=item *
-
-no_op - a method with an empty body
-
-=item *
-
-croak - a method which will croak if called
-
-=item *
-
-method_init - calls other methods from a list of method name => argument pairs
-
-=item *
-
-forward_methods - delegates to an object provided by another method
-
-=back
-
-=head2 Template::Ref (Any Instance)
-
-Methods for deep copies and comparisons
-
-=over 4
-
-=item *
-
-clone: make a deep copy of an object instance
-
-=item *
-
-prototype: make new objects by cloning a typical instance
-
-=item *
-
-compare: compare one object to another
-
-=back
-
-
-=head2 Template::Generic (Abstract)
-
-The remaining subclasses inherit a similar collection of templates from Template::Generic, and provide a different type of scoping or binding for the functionality defined by the Generic template. See L<Class::MakeMethods::Template::Generic> for details.
-
-
-=head2 Template::Hash (Generic, Instances)
-
-The most commonly used implementation, for objects based on blessed hashes.
-
-=over 4
-
-=item *
-
-new: create and copy instances
-
-=item *
-
-scalar: get and set scalar values in each instance
-
-=item *
-
-string: get and set string values in each instance
-
-=item *
-
-number: get and set numeric values in each instance
-
-=item *
-
-boolean: get and set boolean values in each instance
-
-=item *
-
-bits: get and set boolean values stored in a single value in each
-instance
-
-=item *
-
-array: get and set values stored in an array refered to in each
-instance
-
-=item *
-
-struct - methods for acccessing values which are stored by
-position in an array
-
-=item *
-
-hash: get and set values in a hash refered to in each instance
-
-=item *
-
-tiedhash: get and set values in a tied hash refered to in each
-instance
-
-=item *
-
-hash_of_arrays: for references to hashes of arrays contained in each
-instance
-
-=item *
-
-object: set or access a reference to an object contained in each
-instance
-
-=item *
-
-array_of_objects: manipulate an array of object references within in
-each instance
-
-=item *
-
-code: set or call a function reference contained in each instance
-
-=back
-
-
-=head2 Template::Struct (Generic, Instances)
-
-Methods for manipulating positional values in arrays.
-
-=over 4
-
-=item *
-
-new: create and copy array instances
-
-=item *
-
-scalar: get and set scalar values in a given array position
-
-=item *
-
-string: get and set string values in a given array position
-
-=item *
-
-number: get and set numeric values in a given array position
-
-=item *
-
-boolean: get and set boolean values in a given array position
-
-=item *
-
-builtin_isa: generates a wrapper around some builtin function,
-cacheing the results in the object and providing a by-name interface
-
-=back
-
-
-
-=head2 Template::Scalar (Generic, Instances)
-
-For objects based on blessed scalars.
-
-Note that these objects can generally only have one value accessor method, as all such accessors will refer to the same value.
-
-=over 4
-
-=item *
-
-new: create and copy instances
-
-=item *
-
-scalar: get and set scalar values in each instance
-
-=item *
-
-string: get and set a string value in each instance
-
-=item *
-
-number: get and set a numeric value in each instance
-
-=item *
-
-boolean: get and set a boolean value in each instance
-
-=item *
-
-bits: get and set boolean values stored in a single value in each
-instance
-
-=item *
-
-code: set or call a function reference contained in each instance
-
-=back
-
-
-=head2 Template::Flyweight (Generic, Instances)
-
-Stores values for objects in an external location hashed by identity.
-
-Note that while the below constructor creates and returns scalar
-references, accessor methods can be created with this implementation
-for use with any type of object.
-
-=over 4
-
-=item *
-
-new: create and copy instances
-
-=item *
-
-scalar: get and set scalar values associated with each instance
-
-=item *
-
-string: get and set string values associated with each instance
-
-=item *
-
-string_index: get and set string values associated with each
-instance, and maintain an index of instances by value
-
-=item *
-
-number: get and set numeric values associated with each instance
-
-=item *
-
-boolean: get and set boolean values associated with each instance
-
-=item *
-
-boolean_index: get and set boolean values associated with each instance, and maintain a list of items which have the flag set
-
-=item *
-
-bits: get and set boolean values stored in a single value associated with each
-instance
-
-=item *
-
-array: get and set values stored in an array associated with each
-instance
-
-=item *
-
-hash: get and set values in a hash associated with each instance
-
-=item *
-
-code: set or call a function reference associated with each instance
-
-=back
-
-
-=head2 Template::Static (Generic, Global)
-
-Static methods are not instance-dependent; calling them by class
-name or from any instance will consistently access the same value.
-
-=over 4
-
-=item *
-
-scalar: get and set a global scalar value
-
-=item *
-
-string: get and set a global string value
-
-=item *
-
-number: get and set a global number value
-
-=item *
-
-boolean: get and set a global boolean value
-
-=item *
-
-array: get and set values in a global array
-
-=item *
-
-hash: get and set values in a global hash
-
-=item *
-
-tiedhash: get and set values in a global tied hash
-
-=item *
-
-hash_of_arrays: get and set values in a global hash of arrays
-
-=item *
-
-object: set and access a global reference to an object
-
-=item *
-
-instance: set and access a global reference to an object of the declaring class
-
-=item *
-
-code: set and access a global reference to a subroutine.
-
-=back
-
-
-=head2 Template::PackageVar (Generic, Global)
-
-PackageVar methods access a variable in the declaring package. Thus,
-they have the same effect as Static methods, while keeping their
-value accessible via the symbol table.
-
-=over 4
-
-=item *
-
-scalar: get and set a global scalar value
-
-=item *
-
-string: get and set a global string value
-
-=item *
-
-number: get and set a global number value
-
-=item *
-
-boolean: get and set a global boolean value
-
-=item *
-
-array: get and set values in a global array
-
-=item *
-
-hash: get and set values in a global hash
-
-=back
-
-
-=head2 Template::Class (Generic, Global)
-
-Class methods are similar to Static methods, except that each subclass and its instances will access a distinct value.
-
-=over 4
-
-=item *
-
-scalar: get and set a class-specific scalar value
-
-=item *
-
-string: get and set a class-specific string value
-
-=item *
-
-number: get and set a class-specific number value
-
-=item *
-
-boolean: get and set a class-specific boolean value
-
-=item *
-
-array: get and set values in a class-specific array
-
-=item *
-
-hash: get and set values in a class-specific hash
-
-=back
-
-
-=head2 Template::ClassVar (Generic, Global)
-
-ClassVar methods access a variable in the package on which they
-are called.  Thus, they have the same effect as Class methods,
-while keeping their value accessible via the symbol table, like
-PackageVar.
-
-=over 4
-
-=item *
-
-scalar: get and set a class-specific scalar value
-
-=item *
-
-string: get and set a class-specific string value
-
-=item *
-
-number: get and set a class-specific number value
-
-=item *
-
-boolean: get and set a class-specific boolean value
-
-=item *
-
-array: get and set values in a class-specific array
-
-=item *
-
-hash: get and set values in a class-specific hash
-
-=back
-
-
-=head2 Template::ClassInherit (Generic, Global)
-
-ClassInherit methods are an intermediate point between Static and Class methods; subclasses inherit their superclass's value until they set their own value, after which they become distinct.
-
-=over 4
-
-=item *
-
-scalar: get and set an inheritable class-specific scalar value
-
-=item *
-
-string: get and set an inheritable class-specific string value
-
-=item *
-
-number: get and set an inheritable class-specific number value
-
-=item *
-
-boolean: get and set an inheritable class-specific boolean value
-
-=item *
-
-array: get and set values in an inheritable class-specific array
-
-=item *
-
-hash: get and set values in an inheritable class-specific hash
-
-=back
+  use Class::MakeMethods ( get_concat => 'y' );
+  
+  y_attributes(undef, 'join', "\t" )
+  print y_attributes(undef, 'join')
 
 
 =head1 EXTENDING
@@ -1545,12 +1124,16 @@ by adding a new interface, and then uses it to create scalar accessor
 methods named access_p and access_q that get and set values for
 the hash keys 'p' and 'q':
 
-  Class::MakeMethods::_metamethod_definition('Hash:scalar')->
+  Class::MakeMethods::Template::Hash->named_method('scalar')->
 	  {'interface'}{'frozzle'} = { 'access_*'=>'get_set' };
 
   package My::Object;
   Class::MakeMethods::Template::Hash->make( 'scalar' => [ --frozzle => qw( p q ) ] );
 
+  $object->access_p('Potato');    # $object->{p} = 'Potato'
+  print $object->access_q();      # print $object->{q}
+  
+
 Note that this constitutes "action at a distance" and will affect subsequent use by other packages; unless you are "fixing" the current behavior, you are urged to create your own template definition which imports the base behavior of the existing template and overrides the information in question.
 
 Example: The following safely declares a new version of Hash:scalar with the desired additional interface:
@@ -1570,46 +1153,34 @@ Example: The following safely declares a new version of Hash:scalar with the des
 
 =cut
 
-
-=head1 MISCELANEOUS
-
 =head2 Disk Caching
 
-To enable disk caching of generated code, create an empty directory and pass it to the DiskCache package:0
+To enable disk caching of generated code, create an empty directory and pass it to the DiskCache package:
 
   use Class::MakeMethods::Template::DiskCache qw( /my/code/dir );
 
-This has a mixed effect on performance.
+This has a mixed effect on performance, but has the notable advantage of letting you view the subroutines that are being generated by your templates.
 
 See L<Class::MakeMethods::Template::DiskCache> for more information.
 
 
-=head2 Runtime Parameter Access
-
-If the meta-method is defined using an interface which includes the
-attributes method, run-time access to meta-method parameters is
-available.
-
-Example: The following defines a counter meta-method named y, and
-then sets the 'join' parameter for that method.
-
-  use Class::MakeMethods ( get_concat => 'y' );
-  
-  y_attributes(undef, 'join', "\t" )
-  print y_attributes(undef, 'join')
-
-
-
 =head1 SEE ALSO
 
-See L<Class::MakeMethods> for an overview of the method-generation
-framework this is based on.
+=head2 Getting-Started Resources
 
-See L<Class::MakeMethods::Guide> for a getting-started guide,
-annotated examples of usage, and a listing of the method generation
-classes included in this distribution.
+Ron Savage has posted a pair of annotated examples, linked to below.
+Each demonstrates building a class with MakeMethods, and each
+includes scads of comments that walk you through the logic and
+demonstrate how the various methods work together.
 
-See L<Class::MakeMethods::ReadMe> for distribution, installation,
-version and support information.
+  http://savage.net.au/Perl-tutorials.html
+  http://savage.net.au/Perl-tutorials/tut-33.tgz
+  http://savage.net.au/Perl-tutorials/tut-34.tgz
+
+=head2 Package Documentation
+
+See L<Class::MakeMethods> for general information about this distribution. 
+
+See L<Class::MakeMethods::Template> for information about this family of subclasses.
 
 =cut
