@@ -178,23 +178,13 @@ sub object {
 
 =head1 SEE ALSO
 
-If you just need scalar accessors, see L<Class::Data::Inheritable> for a very elegant and efficient implementation.
+See L<Class::MakeMethods> for general information about this distribution. 
+
+See L<Class::MakeMethods::Template> for more about this family of subclasses.
 
 See L<Class::MakeMethods::Template::Generic> for information about the various accessor interfaces subclassed herein.
 
-See L<Class::MakeMethods::ReadMe> for distribution and support information.
-
-
-=head1 LICENSE
-
-This module is free software. It may be used, redistributed and/or
-modified under the same terms as Perl.
-
-Copyright (c) 2001 Evolution Online Systems, Inc.
-
-Developed by:
-
-  M. Simon Cavalletto, Evolution Online Systems, simonm@evolution.com
+If you just need scalar accessors, see L<Class::Data::Inheritable> for a very elegant and efficient implementation.
 
 =cut
 
