@@ -191,22 +191,12 @@ sub compare {
 
 =head1 SEE ALSO
 
-See L<Class::MakeMethods> for a reference to the internals of the Class::MakeMethods framework.
+See L<Class::MakeMethods> for general information about this distribution. 
+
+See L<Class::MakeMethods::Template> for more about this family of subclasses.
 
 See L<Class::MakeMethods::Utility::Ref> for the clone and compare functions used above.
 
-See L<Class::MakeMethods::ReadMe> for distribution and support information.
-
-=head1 LICENSE
-
-Copyright 1998, 2000, 2001 Evolution Online Systems, Inc.
-
-  M. Simon Cavalletto, simonm@evolution.com
-
-Copyright 2002, Matthew Simon Cavalletto.
-
-Derived in part from Ref.pm, Copyright 1994, David Muir Sharnoff.
-
 =cut
 
 ######################################################################
